import { BatchExecuteStatementCommandInput, BatchExecuteStatementCommandOutput, BatchGetCommandInput, BatchGetCommandOutput, BatchWriteCommandInput, BatchWriteCommandOutput, DeleteCommandInput, DeleteCommandOutput, ExecuteStatementCommandInput, ExecuteStatementCommandOutput, ExecuteTransactionCommandInput, ExecuteTransactionCommandOutput, GetCommandInput, GetCommandOutput, PutCommandInput, PutCommandOutput, QueryCommandInput, QueryCommandOutput, ScanCommandInput, ScanCommandOutput, TransactGetCommandInput, TransactGetCommandOutput, TransactWriteCommandInput, TransactWriteCommandOutput, UpdateCommandInput, UpdateCommandOutput } from "@aws-sdk/lib-dynamodb";
import { HttpHandlerOptions as __HttpHandlerOptions } from "@aws-sdk/types";
import { ConditionalCheckFailedError, DuplicateItemError, IdempotentParameterMismatchError, InternalServerError, InvalidEndpointError, ItemCollectionSizeLimitExceededError, ProvisionedThroughputExceededError, RequestLimitExceededError, ResourceNotFoundError, SdkError, TransactionCanceledError, TransactionConflictError, TransactionInProgressError } from "@effect-aws/client-dynamodb";
import { Context, Effect, Layer } from "effect";
import { DynamoDBDocumentClientInstance } from "./DynamoDBDocumentClientInstance";
/**
 * @since 1.0.0
 * @category models
 */
export interface DynamoDBDocumentService {
    readonly _: unique symbol;
    /**
     * @see {@link BatchExecuteStatementCommand}
     */
    batchExecuteStatement(args: BatchExecuteStatementCommandInput, options?: __HttpHandlerOptions): Effect.Effect<BatchExecuteStatementCommandOutput, SdkError | InternalServerError | RequestLimitExceededError>;
    /**
     * @see {@link BatchGetCommand}
     */
    batchGet(args: BatchGetCommandInput, options?: __HttpHandlerOptions): Effect.Effect<BatchGetCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link BatchWriteCommand}
     */
    batchWrite(args: BatchWriteCommandInput, options?: __HttpHandlerOptions): Effect.Effect<BatchWriteCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link DeleteCommand}
     */
    delete(args: DeleteCommandInput, options?: __HttpHandlerOptions): Effect.Effect<DeleteCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link ExecuteStatementCommand}
     */
    executeStatement(args: ExecuteStatementCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ExecuteStatementCommandOutput, SdkError | ConditionalCheckFailedError | DuplicateItemError | InternalServerError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link ExecuteTransactionCommand}
     */
    executeTransaction(args: ExecuteTransactionCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ExecuteTransactionCommandOutput, SdkError | IdempotentParameterMismatchError | InternalServerError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError>;
    /**
     * @see {@link GetCommand}
     */
    get(args: GetCommandInput, options?: __HttpHandlerOptions): Effect.Effect<GetCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link PutCommand}
     */
    put(args: PutCommandInput, options?: __HttpHandlerOptions): Effect.Effect<PutCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link QueryCommand}
     */
    query(args: QueryCommandInput, options?: __HttpHandlerOptions): Effect.Effect<QueryCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link ScanCommand}
     */
    scan(args: ScanCommandInput, options?: __HttpHandlerOptions): Effect.Effect<ScanCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link TransactGetCommand}
     */
    transactGet(args: TransactGetCommandInput, options?: __HttpHandlerOptions): Effect.Effect<TransactGetCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError>;
    /**
     * @see {@link TransactWriteCommand}
     */
    transactWrite(args: TransactWriteCommandInput, options?: __HttpHandlerOptions): Effect.Effect<TransactWriteCommandOutput, SdkError | IdempotentParameterMismatchError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError>;
    /**
     * @see {@link UpdateCommand}
     */
    update(args: UpdateCommandInput, options?: __HttpHandlerOptions): Effect.Effect<UpdateCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
}
/**
 * @since 1.0.0
 * @category tags
 */
export declare const DynamoDBDocumentService: Context.Tag<DynamoDBDocumentService, DynamoDBDocumentService>;
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeDynamoDBDocumentService: Effect.Effect<DynamoDBDocumentService, never, DynamoDBDocumentClientInstance>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const BaseDynamoDBDocumentServiceLayer: Layer.Layer<DynamoDBDocumentService, never, DynamoDBDocumentClientInstance>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const DynamoDBDocumentServiceLayer: Layer.Layer<DynamoDBDocumentService, never, import("./DynamoDBDocumentClientInstanceConfig").DynamoDBDocumentClientInstanceConfig>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const DefaultDynamoDBDocumentServiceLayer: Layer.Layer<DynamoDBDocumentService, never, never>;
